﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="AddServiceCertificateCommand.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace AzureManagement.AzureCommands
{
    using System;

    using AzureManagement.AzureDataContracts;

    using Common;

    using RestClient;

    public class AddServiceCertificateCommand : AzureManagementCommand
    {
        private readonly string serviceName;

        private readonly CertificateFile certificateFile;

        public AddServiceCertificateCommand(IAzureServiceContext serviceContext, string serviceName, CertificateFile certificateFile)
            : base(serviceContext)
        {
            if (string.IsNullOrEmpty(serviceName))
            {
                throw new ArgumentException("Service name must not be null or empty.", "serviceName");
            }

            if (certificateFile == null)
            {
                throw new ArgumentNullException("certificateFile", "Certificate must not be null.");
            }

            this.serviceName = serviceName;
            this.certificateFile = certificateFile;
        }

        protected override RequestContext GetRequestContext()
        {
            return this.CreatePostOperationRequestContext();
        }

        protected override string FormatPath(IAzureServiceContext azureServiceContext)
        {
            return string.Format("{0}/services/hostedservices/{1}/certificates", azureServiceContext.SubscriptionId, this.serviceName);
        }

        protected override string FormatBody()
        {
            return XmlHelper.Serialize(this.certificateFile);
        }
    }
}