﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="CreateDeploymentCommand.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace AzureManagement.AzureCommands
{
    using System;

    using AzureManagement.AzureDataContracts;

    using Common;

    using RestClient;

    public class CreateDeploymentCommand : AzureManagementCommand
    {
        private readonly string serviceName;

        private readonly DeploymentSlots deploymentSlot;

        private readonly CreateDeployment createDeployment;

        public CreateDeploymentCommand(
            IAzureServiceContext serviceContext, 
            string serviceName, 
            DeploymentSlots deploymentSlot, 
            CreateDeployment createDeployment)
            : base(serviceContext)
        {
            if (string.IsNullOrEmpty(serviceName))
            {
                throw new ArgumentException("Service name must not be null or empty.", "serviceName");
            }

            if (createDeployment == null)
            {
                throw new ArgumentNullException("createDeployment", "Deployment parameters must not be null.");
            }

            this.serviceName = serviceName;
            this.deploymentSlot = deploymentSlot;
            this.createDeployment = createDeployment;
        }

        protected override RequestContext GetRequestContext()
        {
            return this.CreatePostOperationRequestContext();
        }

        protected override string FormatPath(IAzureServiceContext azureServiceContext)
        {
            return string.Format(
                "{0}/services/hostedservices/{1}/deploymentslots/{2}", 
                azureServiceContext.SubscriptionId, 
                this.serviceName, 
                this.deploymentSlot.ToString().ToLower());
        }

        protected override string FormatBody()
        {
            return XmlHelper.Serialize(this.createDeployment);
        }
    }
}