﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="ListJobsCommand.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace HpcSchedulerManagement.Commands
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using RestClient;

    public class ListJobsCommand : HpcSchedulerCommandBase
    {
        private readonly string hpcClusterName;

        private readonly string continuationToken;

        private readonly string owner;

        private readonly IEnumerable<string> properties;

        public ListJobsCommand(
                        IHpcSchedulerServiceContext serviceContext, 
                        string hpcClusterName, 
                        IEnumerable<string> properties, 
                        string continuationToken = null, 
                        string owner = null) 
            : base(serviceContext)
        {
            if (string.IsNullOrEmpty(hpcClusterName))
            {
                throw new ArgumentException("Hpc cluster name must not be null or empty.", "hpcClusterName");
            }

            this.hpcClusterName = hpcClusterName;
            this.properties = properties;
            this.continuationToken = continuationToken;
            this.owner = owner;
        }

        protected override RequestContext GetRequestContext()
        {
            return this.CreateGetOperationRequestContext();
        }

        protected override string FormatPath(IHpcSchedulerServiceContext serviceContext)
        {
            return string.Format("{0}/Jobs", this.hpcClusterName);
        }

        protected override void AddParameters(RequestContext requestContext)
        {
            base.AddParameters(requestContext);

            if (this.properties != null && this.properties.Any())
            {
                requestContext.AddParameter(HpcSchedulerServiceQueryParameters.Properties, string.Join(",", this.properties));
            }

            if (!string.IsNullOrEmpty(this.continuationToken))
            {
                requestContext.AddParameter(HpcSchedulerServiceQueryParameters.QueryId, this.continuationToken);
            }

            if (!string.IsNullOrEmpty(this.owner))
            {
                requestContext.AddParameter(HpcSchedulerServiceQueryParameters.Owner, this.owner);
            }
        }
    }
}