﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="ListTasksCommand.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace HpcSchedulerManagement.Commands
{
    using System;

    using System.Collections.Generic;
    using System.Linq;

    using RestClient;

    public class ListTasksCommand : HpcSchedulerCommandBase
    {
        private readonly string hpcClusterName;

        private readonly int jobId;

        private readonly IEnumerable<string> properties;

        private readonly bool expand;

        private readonly string continuationToken;

        public ListTasksCommand(
                        IHpcSchedulerServiceContext serviceContext, 
                        string hpcClusterName, 
                        int jobId, 
                        IEnumerable<string> properties, 
                        bool expand = false, 
                        string continuationToken = null) : base(serviceContext)
        {
            if (string.IsNullOrEmpty(hpcClusterName))
            {
                throw new ArgumentException("Hpc cluster name must not be null or empty.", "hpcClusterName");
            }

            if (jobId <= 0)
            {
                throw new ArgumentException("Job id must not be less than or equal to 0.", "jobId");
            }

            this.hpcClusterName = hpcClusterName;
            this.jobId = jobId;
            this.properties = properties;
            this.expand = expand;
            this.continuationToken = continuationToken;
        }

        protected override RequestContext GetRequestContext()
        {
            return this.CreateGetOperationRequestContext();
        }

        protected override string FormatPath(IHpcSchedulerServiceContext serviceContext)
        {
            return string.Format("{0}/Job/{1}/Tasks", this.hpcClusterName, this.jobId);
        }

        protected override void AddParameters(RequestContext requestContext)
        {
            base.AddParameters(requestContext);

            if (this.properties != null && this.properties.Any())
            {
                requestContext.AddParameter(HpcSchedulerServiceQueryParameters.Properties, string.Join(",", this.properties));
            }
            
            requestContext.AddParameter(HpcSchedulerServiceQueryParameters.ExpandParametric, this.expand.ToString());

            if (!string.IsNullOrEmpty(this.continuationToken))
            {
                requestContext.AddParameter(HpcSchedulerServiceQueryParameters.QueryId, this.continuationToken);
            }
        }
    }
}