﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="GetSchedulerJobListCmdlet.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace CloudBlitz.Powershell.Cmdlets
{
    using System;
    using System.Collections.Generic;
    using System.Management.Automation;

    [Cmdlet(VerbsCommon.Get, "SchedulerJobList")]
    public class GetSchedulerJobListCmdlet : HpcSchedulerCmdletBase
    {
        [Parameter]
        public string Properties { get; set; }

        protected override void ProcessRecord()
        {
            try
            {
                base.ProcessRecord();
                this.GetSchedulerJobListProcess();
            }
            catch (Exception ex)
            {
                this.ThrowTerminatingError(this.HandleException(ex).Result);
            }
        }

        private void GetSchedulerJobListProcess()
        {
            var client = this.CreateClient();

            IEnumerable<string> propertiesToList = null;
            if (!string.IsNullOrEmpty(this.Properties))
            {
                propertiesToList = this.Properties.Split(new[] { "," }, StringSplitOptions.RemoveEmptyEntries);
            }

            var jobs = client.ListJobs(this.Credentials.ClusterName, propertiesToList).Result;

            this.WriteObject(jobs);
        }         
    }
}