﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="Microsoft Corp." file="GetSchedulerTaskCmdlet.cs">
//   All rights reserved. See License.txt in the project root for license information.
// </copyright>
// 
// --------------------------------------------------------------------------------------------------------------------
namespace CloudBlitz.Powershell.Cmdlets
{
    using System;
    using System.Collections.Generic;
    using System.Management.Automation;

    [Cmdlet(VerbsCommon.Get, "SchedulerTask")]
    public class GetSchedulerTaskCmdlet : HpcSchedulerCmdletBase
    {
        [Parameter(Mandatory = true)]
        [ValidateNotNullOrEmpty]
        public int JobId { get; set; }

        [Parameter(Mandatory = true)]
        [ValidateNotNullOrEmpty]
        public int TaskId { get; set; }

        [Parameter]
        public string Properties { get; set; }

        protected override void ProcessRecord()
        {
            try
            {
                base.ProcessRecord();
                this.GetSchedulerTaskProcess();
            }
            catch (Exception ex)
            {
                this.ThrowTerminatingError(this.HandleException(ex).Result);
            }
        }

        private void GetSchedulerTaskProcess()
        {
            var client = this.CreateClient();

            IEnumerable<string> propertiesToList = null;
            if (!string.IsNullOrEmpty(this.Properties))
            {
                propertiesToList = this.Properties.Split(new[] { "," }, StringSplitOptions.RemoveEmptyEntries);
            }

            var task = client.GetTask(this.Credentials.ClusterName, this.JobId, this.TaskId, propertiesToList).Result;

            this.WriteObject(task);
        }
    }
}